.. _cisco.asa.asa_cliconf:


*************
cisco.asa.asa
*************

**Use asa cliconf to run command on Cisco ASA platform**


Version added: 1.0.0

.. contents::
   :local:
   :depth: 1


Synopsis
--------
- This asa plugin provides low level abstraction apis for sending and receiving CLI commands from Cisco ASA network devices.











Status
------


Authors
~~~~~~~

- Ansible Security Team

.. hint::
    Configuration entries for each entry type have a low to high priority order. For example, a variable that is lower in the list will override a variable that is higher up.
